@@ -4,10 +4,11 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
+use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(trim_blank_lines ellipsis indent);
+our @EXPORT_OK = qw(trim_blank_lines ellipsis indent linenum);
 
 sub trim_blank_lines {
     local $_ = shift;
@@ -41,6 +42,26 @@ sub indent {
     $str;
 }
 
+sub linenum {
+    my ($str, $opts) = @_;
+    $opts //= {};
+    $opts->{width}      //= 4;
+    $opts->{zeropad}    //= 0;
+    $opts->{skip_empty} //= 1;
+
+    my $i = 0;
+    $str =~ s/^((\S)?.*)/
+        sprintf(join("",
+                     "%",
+                     ($opts->{zeropad} && !($opts->{skip_empty} && !defined($2)) ? "0" : ""),
+                     $opts->{width}, "s",
+                     "|%s"),
+                ++$i && $opts->{skip_empty} && !defined($2) ? "" : $i,
+                $1)/meg;
+
+    $str;
+}
+
 1;
 # ABSTRACT: String utilities
 
@@ -54,7 +75,7 @@ SHARYANTO::String::Util - String utilities
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 FUNCTIONS
 
@@ -86,6 +107,41 @@ or more whitespaces).
 
 =back
 
+=head2 linenum($str, \%opts) => STR
+
+Add line numbers. For example:
+
+     1|line1
+     2|line2
+      |
+     4|line4
+
+Known options:
+
+=over 4
+
+=item * width => INT (default: 4)
+
+=item * zeropad => BOOL (default: 0)
+
+If turned on, will output something like:
+
+  0001|line1
+  0002|line2
+      |
+  0004|line4
+
+=item * skip_empty => BOOL (default: 1)
+
+If set to false, keep printing line number even if line is empty:
+
+     1|line1
+     2|line2
+     3|
+     4|line4
+
+=back
+
 =head1 FAQ
 
 =head2 What is this?
